package com.ssj.service.sys.finance.service.impl;

import com.ssj.dao.sys.fx.dao.FinanceQueryDao;
import com.ssj.service.sys.finance.service.IFinanceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

import javax.transaction.Transactional;
import java.util.List;
import java.util.Map;

@Service
@Transactional
public class FinanceServiceImpl implements IFinanceService {

    @Autowired
    private FinanceQueryDao dao;

    @Override
    public List<Map<String, Object>> findLittleShuAllList(Map<String, Object> params) {
        return dao.findLittleShuAllList(params);
    }

    @Override
    public Page<Map<String, Object>> littleMonthDetailList(Map<String, Object> params, Pageable initPage) {
        return dao.littleMonthDetailList(params,initPage);
    }

    @Override
    public Page<Map<String, Object>> littleDetailList(Map<String, Object> params, Pageable initPage) {
        return dao.littleDetailList(params,initPage);
    }

	@Override
	public Page<Map<String, Object>> findDeviceBalanceAndLossList(Map<String, Object> params, Pageable pageable) {
		return dao.findDeviceBalanceAndLossList(params, pageable);
	}

	@Override
	public Page<Map<String, Object>> findDeviceBalanceList(Map<String, Object> params, Pageable pageable) {
		return dao.findDeviceBalanceList(params, pageable);
	}

	@Override
	public Page<Map<String, Object>> balanceConsumeDetailList(Map<String, Object> params, Pageable pageable) {
		return dao.balanceConsumeDetailList(params, pageable);
	}

	@Override
	public Page<Map<String, Object>> balanceConsumeDetailList_New(Map<String, Object> params, Pageable pageable) {
		return dao.balanceConsumeDetailList_New(params, pageable);
	}
}
