package com.ssj.dao.sys.fx.dao;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.util.List;
import java.util.Map;

public interface FinanceQueryDao {
    List<Map<String, Object>> findLittleShuAllList(Map<String, Object> params);

    Page<Map<String, Object>> littleMonthDetailList(Map<String, Object> params, Pageable initPage);

    Page<Map<String, Object>> littleDetailList(Map<String, Object> params, Pageable initPage);
    
    Page<Map<String, Object>> findDeviceBalanceAndLossList(Map<String, Object> params, Pageable pageable);
    
    Page<Map<String, Object>> findDeviceBalanceList(Map<String, Object> params, Pageable pageable);
    
    Page<Map<String, Object>> balanceConsumeDetailList(Map<String, Object> params, Pageable pageable);
    
    Page<Map<String, Object>> balanceConsumeDetailList_New(Map<String, Object> params, Pageable pageable);
    
}
